@@ -18,14 +18,13 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs.h>
-
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-file.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
+#include <libanjuta/interfaces/ianjuta-file-manager.h>
+#include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
 #include <libanjuta/interfaces/ianjuta-vcs.h>
 
@@ -76,7 +75,7 @@ static GtkActionEntry actions_cvs[] = {
 		GTK_STOCK_REFRESH,         /* Stock icon, if any */
 		N_("_Update"),             /* Display label */
 		"<control>u",              /* short-cut */
-		N_("Sync your local copy with the CVS tree"), /* Tooltip */
+		N_("Syncronize your local copy with the CVS tree"), /* Tooltip */
 		G_CALLBACK (on_menu_cvs_update) /* action callback */
 	},
 	{
@@ -135,7 +134,7 @@ static GtkActionEntry popup_actions_cvs[] = {
 		GTK_STOCK_REFRESH,         /* Stock icon, if any */
 		N_("_Update"),             /* Display label */
 		NULL,                      /* short-cut */
-		N_("Sync your local copy with the CVS tree"), /* Tooltip */
+		N_("Syncronize your local copy with the CVS tree"), /* Tooltip */
 		G_CALLBACK (on_fm_cvs_update) /* action callback */
 	},
 	{
@@ -165,22 +164,19 @@ static GtkActionEntry popup_actions_cvs[] = {
 };
 
 static void
-value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
+value_added_fm_current_file (AnjutaPlugin *plugin, const char *name,
 							const GValue *value, gpointer data)
 {
 	AnjutaUI *ui;
 	GtkAction *cvs_menu_action;
-	const gchar *uri;
-	GnomeVFSURI *cvs_uri = NULL;
-	gchar *cvs_text_uri = NULL;
-	gchar *cvs_dir;
 	gchar *filename;
-	GnomeVFSDirectoryHandle* handle;
-	GnomeVFSFileInfo info;
-	GnomeVFSResult result;
+	GFileType type;
+	GFile *cvs_dir;
+	GFileEnumerator *en;
+	GFileInfo *file_info;
 	
-	uri = g_value_get_string (value);
-	filename = gnome_vfs_get_local_path_from_uri (uri);
+	GFile* file = G_FILE (g_value_get_object (value));
+	filename = g_file_get_path (file);
 	g_return_if_fail (filename != NULL);
 
 	CVSPlugin *cvs_plugin = ANJUTA_PLUGIN_CVS (plugin);
@@ -195,41 +191,56 @@ value_added_fm_current_uri (AnjutaPlugin *plugin, const char *name,
 	
 	/* If a directory is selected we check if it contains a "CVS" directory,
 	if it is a file we check if it's directory contains a "CVS" directory */
-	result = gnome_vfs_get_file_info(uri, &info, 
-		GNOME_VFS_FILE_INFO_DEFAULT);
-	if (result == GNOME_VFS_OK)
+	file_info = g_file_query_info (file,
+			G_FILE_ATTRIBUTE_STANDARD_TYPE,
+			G_FILE_QUERY_INFO_NONE, NULL, NULL);
+
+	if (file_info == NULL)
 	{
-		if (info.type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+		return;
+	}
+
+	type = g_file_info_get_attribute_uint32 (file_info, 
+			G_FILE_ATTRIBUTE_STANDARD_TYPE);
+	g_object_unref (file_info);
+	if (type == G_FILE_TYPE_DIRECTORY)
+	{
+		cvs_dir = g_file_get_child (file, "CVS");
+	}
+	
+	else
+	{
+		GFile *parent;
+
+		parent = g_file_get_parent (file);
+		if (parent != NULL)
 		{
-			cvs_dir = g_strconcat(uri, "/CVS", NULL);
+			cvs_dir = g_file_get_child (parent, "CVS"); 
+			g_object_unref (G_OBJECT (parent));
 		}
-		
 		else
 		{
-			cvs_uri = gnome_vfs_uri_new (uri);
-			cvs_text_uri = gnome_vfs_uri_extract_dirname(cvs_uri);
-			cvs_dir = g_strconcat(cvs_text_uri, "/CVS", NULL);
-			g_free(cvs_text_uri);
-			gnome_vfs_uri_unref(cvs_uri);
-		}	
-	}
-	else
-		return; /* Strange... */
-	if (gnome_vfs_directory_open(&handle, cvs_dir, 
-		GNOME_VFS_FILE_INFO_DEFAULT) == GNOME_VFS_OK) 
+			cvs_dir = g_file_new_for_path ("/CVS");
+		}
+	}	
+
+	en = g_file_enumerate_children (cvs_dir, "", 
+			G_FILE_QUERY_INFO_NONE,
+			NULL, NULL);
+	if (en != NULL)
 	{
-		
+		g_object_unref (G_OBJECT (en));
 		g_object_set (G_OBJECT (cvs_menu_action), "sensitive", TRUE, NULL);
 	}
 	else
 	{
 		g_object_set (G_OBJECT (cvs_menu_action), "sensitive", FALSE, NULL);
 	}
-	g_free (cvs_dir);
+	g_object_unref (cvs_dir);
 }
 
 static void
-value_removed_fm_current_uri (AnjutaPlugin *plugin,
+value_removed_fm_current_file (AnjutaPlugin *plugin,
 							  const char *name, gpointer data)
 {
 	AnjutaUI *ui;
@@ -256,7 +267,7 @@ value_added_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 
 	bb_plugin = ANJUTA_PLUGIN_CVS (plugin);
 	
-	DEBUG_PRINT ("Project added");
+	DEBUG_PRINT ("%s", "Project added");
 	
 	if (bb_plugin->project_root_dir)
 		g_free (bb_plugin->project_root_dir);
@@ -266,7 +277,7 @@ value_added_project_root_uri (AnjutaPlugin *plugin, const gchar *name,
 	if (root_uri)
 	{
 		bb_plugin->project_root_dir =
-			gnome_vfs_get_local_path_from_uri (root_uri);
+			anjuta_util_get_local_path_from_uri (root_uri);
 		if (bb_plugin->project_root_dir)
 		{
 			// update_project_ui (bb_plugin);
@@ -292,7 +303,7 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 							const GValue *value, gpointer data)
 {
 	AnjutaUI *ui;
-	gchar *uri;
+	GFile* file;
 	GObject *editor;
 	
 	editor = g_value_get_object (value);
@@ -307,16 +318,15 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 		g_free (cvs_plugin->current_editor_filename);
 	cvs_plugin->current_editor_filename = NULL;
 	
-	uri = ianjuta_file_get_uri (IANJUTA_FILE (editor), NULL);
-	if (uri)
+	file = ianjuta_file_get_file (IANJUTA_FILE (editor), NULL);
+	if (file)
 	{
 		gchar *filename;
 		
-		filename = gnome_vfs_get_local_path_from_uri (uri);
+		filename = g_file_get_path (file);
 		g_return_if_fail (filename != NULL);
 		cvs_plugin->current_editor_filename = filename;
-		g_free (uri);
-		// update_module_ui (cvs_plugin);
+		g_object_unref (file);
 	}
 }
 
@@ -339,7 +349,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	AnjutaUI *ui;
 	CVSPlugin *cvs_plugin;
 	
-	DEBUG_PRINT ("CVSPlugin: Activating CVS plugin ...");
+	DEBUG_PRINT ("%s", "CVSPlugin: Activating CVS plugin ...");
 	cvs_plugin = ANJUTA_PLUGIN_CVS (plugin);
 	
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
@@ -362,15 +372,15 @@ activate_plugin (AnjutaPlugin *plugin)
 	
 	/* Add watches */
 	cvs_plugin->fm_watch_id = 
-		anjuta_plugin_add_watch (plugin, "file_manager_current_uri",
-								 value_added_fm_current_uri,
-								 value_removed_fm_current_uri, NULL);
+		anjuta_plugin_add_watch (plugin, IANJUTA_FILE_MANAGER_SELECTED_FILE,
+								 value_added_fm_current_file,
+								 value_removed_fm_current_file, NULL);
 	cvs_plugin->project_watch_id = 
-		anjuta_plugin_add_watch (plugin, "project_root_uri",
+		anjuta_plugin_add_watch (plugin, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 								 value_added_project_root_uri,
 								 value_removed_project_root_uri, NULL);
 	cvs_plugin->editor_watch_id = 
-		anjuta_plugin_add_watch (plugin, "document_manager_current_editor",
+		anjuta_plugin_add_watch (plugin, IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								 value_added_current_editor,
 								 value_removed_current_editor, NULL);
 	return TRUE;
@@ -382,7 +392,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	AnjutaUI *ui;
 	CVSPlugin *cvs_plugin;
 	
-	DEBUG_PRINT ("CVSPlugin: Dectivating CVS plugin ...");
+	DEBUG_PRINT ("%s", "CVSPlugin: Dectivating CVS plugin ...");
 	
 	cvs_plugin = ANJUTA_PLUGIN_CVS (plugin);
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
@@ -443,51 +453,19 @@ cvs_plugin_class_init (GObjectClass *klass)
 	klass->finalize = finalize;
 }
 
-/* Interface */
-
-static void
-ianjuta_cvs_add (IAnjutaVcs *obj, const gchar* filename, 
-	GError **err)
-{
-	anjuta_cvs_add(ANJUTA_PLUGIN(obj), filename, FALSE, err);
-}
-	
-static void
-ianjuta_cvs_commit (IAnjutaVcs *obj, const gchar* filename, const gchar* log, 
-						 gboolean recurse, GError **err)
-{
-	anjuta_cvs_commit (ANJUTA_PLUGIN(obj), filename, log, "", recurse, err);
-}
-
-static void
-ianjuta_cvs_remove (IAnjutaVcs *obj, const gchar* filename, GError **err)
-{
-	anjuta_cvs_remove (ANJUTA_PLUGIN(obj), filename, err);
-}
-
-
-static void
-ianjuta_cvs_update (IAnjutaVcs *obj, const gchar* filename, gboolean recurse, GError **err)
-{
-	anjuta_cvs_update(ANJUTA_PLUGIN(obj), filename, recurse, FALSE, TRUE, FALSE,"", err);}
-
-static void
-ianjuta_vcs_iface_init (IAnjutaVcsIface *iface)
-{
-	iface->add = ianjuta_cvs_add;
-	iface->remove = ianjuta_cvs_remove;
-	iface->update = ianjuta_cvs_update;
-	iface->commit = ianjuta_cvs_commit;	
-}
-
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
 	/* Create the messages preferences page */
-	GladeXML* gxml;
-	gxml = glade_xml_new (GLADE_FILE, "cvs", NULL);
-	anjuta_preferences_add_page (prefs, gxml, "cvs", _("CVS"), ICON_FILE);
-	g_object_unref (gxml);
+	GError* error = NULL;
+	GtkBuilder *bxml = gtk_builder_new();
+	if (!gtk_builder_add_from_file(bxml, GLADE_FILE, &error))
+	{
+		g_warning("Couldn't load builder file: %s", error->message);
+		g_error_free(error);
+	}
+	anjuta_preferences_add_from_builder (prefs, bxml, "cvs", _("CVS"), ICON_FILE);
+	g_object_unref (bxml);
 }
 
 static void
@@ -504,7 +482,6 @@ ipreferences_iface_init(IAnjutaPreferencesIface* iface)
 }
 
 ANJUTA_PLUGIN_BEGIN (CVSPlugin, cvs_plugin);
-ANJUTA_PLUGIN_ADD_INTERFACE(ianjuta_vcs, IANJUTA_TYPE_VCS);
 ANJUTA_PLUGIN_ADD_INTERFACE(ipreferences, IANJUTA_TYPE_PREFERENCES);
 ANJUTA_PLUGIN_END;
 
